@@ -83,7 +83,7 @@ sub gst_service_sysv_get_paths
        "debian-sarge" => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "ubuntu-5.04"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        "ubuntu-5.10"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
-       "ubuntu-6.04"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
+       "ubuntu-6.06"  => ["$gst_prefix/etc", "$gst_prefix/etc/init.d", "../init.d"],
        
        "suse-7.0"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d", "../"],
        "suse-9.0"     => ["$gst_prefix/etc/init.d", "$gst_prefix/etc/init.d", "../"],
@@ -99,6 +99,7 @@ sub gst_service_sysv_get_paths
        "fedora-2"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
        "fedora-3"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
        "fedora-4"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
+       "fedora-5"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
        "rpath"        => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
 
        "vine-3.0"     => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
@@ -169,6 +170,7 @@ sub gst_service_sysv_get_runlevels
        "fedora-2"       => [3, 5],
        "fedora-3"       => [3, 5],
        "fedora-4"       => [3, 5],
+       "fedora-5"       => [3, 5],
        "rpath"          => [3, 5],
        
        "vine-3.0"       => [3, 5],
@@ -236,6 +238,7 @@ sub gst_service_get_runlevel_roles
      "fedora-2"       => "redhat-5.2",
      "fedora-3"       => "redhat-5.2",
      "fedora-4"       => "redhat-5.2",
+     "fedora-5"       => "redhat-5.2",
      "rpath"          => "redhat-5.2",
 
      "vine-3.0"       => "redhat-5.2",
@@ -1713,6 +1716,7 @@ sub gst_service_get_status
        "fedora-2"     => \&gst_service_redhat_get_status,
        "fedora-3"     => \&gst_service_redhat_get_status,
        "fedora-4"     => \&gst_service_redhat_get_status,
+       "fedora-5"     => \&gst_service_redhat_get_status,
 
        "rpath"        => \&gst_service_redhat_get_status,
 
